%This matlab file reads the data generated by the Analysis Sequences
%in the DemoModels and plots the comparisons between Coustyx results 
%and Analytical results.

%********************************************************************
%Compare results from coustyx and analytical solutions for 
%Spherical Harmonic Excitation radiation problem

%********************************************************************
%Input:
%  Run the following Analysis Sequences in the Demo Model,
%  before running this matlab script. 
%   (1) RunValidation - FMM
%********************************************************************

resultsFMM = load('validation_results_fmm.txt');

%  Each *.txt results file has 3 columns, where
%    results(:,1) = ka, k=omega/c (wave number), a=1 (sphere radius)
%    results(:,2) = Radiated Sound Power from Coustyx
%    results(:,3) = Radiated Sound Power from Analytical solution
%********************************************************************

%********************************************************************
%Output:
%  (1) plot 1: Plots comparisons between FMM and Analytical results
%********************************************************************

%Acoustic medium properties:
%  rho_o = medium density of air = 1.21 kg.m^3
%  c = speed of sound = 343 m/s
%  u0 = 1 m/s
rho_o = 1.21;
c = 343;
u0 = 1;

%********************************************************************
%Plot FMM and Analytical results
%********************************************************************
figure;
plot(resultsFMM(:,1),resultsFMM(:,2),'r-',...
    resultsFMM(:,1),resultsFMM(:,3),'b.');
legend('Coustyx-FMM','Analytical');
title('Radiated Sound Power');
xlim([0 10]);
xlabel('ka');
ylabel('W, watts');








